﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Controls;
using System.Windows.Media;

namespace LocalJoost.TileSource
{
    public abstract class BaseVETileSource : BaseTileSource
    {

        /// <summary>
        /// Converts tile XY coordinates into a QuadKey at a specified level of detail.
        /// </summary>
        /// <param name="tileX">Tile X coordinate.</param>
        /// <param name="tileY">Tile Y coordinate.</param>
        /// <param name="levelOfDetail">Level of detail, from 1 (lowest detail)
        /// to 23 (highest detail).</param>
        /// <returns>A string containing the QuadKey.</returns>
        private static string TileXYToQuadKey(int tileX, int tileY, int levelOfDetail)
        {
            var quadKey = new StringBuilder();
            for (int i = levelOfDetail; i > 0; i--)
            {
                char digit = '0';
                int mask = 1 << (i - 1);
                if ((tileX & mask) != 0)
                {
                    digit++;
                }
                if ((tileY & mask) != 0)
                {
                    digit++;
                    digit++;
                }
                quadKey.Append(digit);
            }
            return quadKey.ToString();
        }

        /// <summary>
        /// Get tiles for <see cref="MultiScaleImage" />.
        /// </summary>
        /// <param name="tileLevel">Tile Level</param>
        /// <param name="tilePositionX">Tile X position</param>
        /// <param name="tilePositionY">Tile Y position</param>
        /// <param name="tileImageLayerSources">Tile images repository</param>
        protected override void GetTileLayers(int tileLevel, int tilePositionX, int tilePositionY,
                                              IList<object> tileImageLayerSources)
        {
            int zoom = TileToZoom(tileLevel);
            if (zoom > 0)
            {
                string quadKey = TileXYToQuadKey(tilePositionX, tilePositionY, zoom);
                string veLink = string.Format(UriFormat,
                                              new object[] {quadKey[quadKey.Length - 1], quadKey});
                var veUri = new Uri(veLink);
                System.Diagnostics.Debug.WriteLine("adding uri " + veLink);
                tileImageLayerSources.Add(veUri);
            }
        }
    }
}