﻿using System;

namespace LocalJoost.TileSource
{
    public class GoogleTileSource : BaseTileSource
    {
        private int _servernr = 0;
        private char _mapMode;

        private int Server
        {
            get
            {
                return _servernr = (_servernr + 1) % 4;

            }
        }

        public GoogleTileSource(GoogleTileSourceType tileSourceType)
        {
            _mapMode = TypeToMapMode(tileSourceType);
        }

        public override string UriFormat
        {
            get { return @"http://mt{0}.google.com/vt/lyrs={1}&z={2}&x={3}&y={4}"; }
        }

        protected override void GetTileLayers(int tileLevel, int tilePositionX, int tilePositionY,
            System.Collections.Generic.IList<object> tileImageLayerSources)
        {
            var zoom = TileToZoom(tileLevel);
            if (zoom > 0)
            {
                var url = string.Format(UriFormat, Server, _mapMode, zoom, tilePositionX, tilePositionY);
                var veUri = new Uri(url);
                System.Diagnostics.Debug.WriteLine("adding uri " + url);
                tileImageLayerSources.Add(veUri);
            }

        }

        private static char TypeToMapMode(GoogleTileSourceType tileSourceType)
        {
            switch (tileSourceType)
            {
                case GoogleTileSourceType.Hybrid:
                    return 'y';
                case GoogleTileSourceType.Satellite:
                    return 's';
                case GoogleTileSourceType.Street:
                    return 'm';
            }

            return ' ';
        }

    }
}
